==> istio-model-v1alpha3-6.8.0-sources.jar: io/fabric8/istio/api/internal/protobuf/types/ValueNumberValueFluent.java <==
package io.fabric8.istio.api.internal.protobuf.types;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Double;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ValueNumberValueFluent<A extends ValueNumberValueFluent<A>> extends BaseFluent<A>{
  public ValueNumberValueFluent() {
  }
  public ValueNumberValueFluent(ValueNumberValue instance) {
    instance = (instance != null ? instance : new ValueNumberValue());

    if (instance != null) {
      this.withNumberValue(instance.getNumberValue());
      this.withNumberValue(instance.getNumberValue());
    }
  }
  private Double numberValue;
  public Double getNumberValue() {
    return this.numberValue;
  }
  public A withNumberValue(Double numberValue) {
    this.numberValue=numberValue; return (A) this;
  }
  public boolean hasNumberValue() {
    return this.numberValue != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ValueNumberValueFluent that = (ValueNumberValueFluent) o;
    if (!java.util.Objects.equals(numberValue, that.numberValue)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(numberValue,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (numberValue != null) { sb.append("numberValue:"); sb.append(numberValue); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/internal/protobuf/types/ValueNumberValueFluent.java <==
package io.fabric8.istio.api.internal.protobuf.types;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Double;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ValueNumberValueFluent<A extends ValueNumberValueFluent<A>> extends BaseFluent<A>{
  public ValueNumberValueFluent() {
  }
  
  public ValueNumberValueFluent(ValueNumberValue instance) {
    this.copyInstance(instance);
  }
  private Double numberValue;
  
  protected void copyInstance(ValueNumberValue instance) {
    instance = (instance != null ? instance : new ValueNumberValue());
  
    if (instance != null) {
        this.withNumberValue(instance.getNumberValue());
        this.withNumberValue(instance.getNumberValue());
      }
  }
  
  public Double getNumberValue() {
    return this.numberValue;
  }
  
  public A withNumberValue(Double numberValue) {
    this.numberValue=numberValue; return (A) this;
  }
  
  public boolean hasNumberValue() {
    return this.numberValue != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ValueNumberValueFluent that = (ValueNumberValueFluent) o;
    if (!java.util.Objects.equals(numberValue, that.numberValue)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(numberValue,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (numberValue != null) { sb.append("numberValue:"); sb.append(numberValue); }
    sb.append("}");
    return sb.toString();
  }
  

}
